#####################################################################
#	Input															#
#		*BODY														#
#####################################################################
library(ape)
library(vegan)
library(psych)
library(dendextend)
library(ggdendro)
library(pvclust)
library(ggplot2)
library(ggnewscale)
library(wesanderson)

myRealDataBody = read.csv("CerrejonisuchusSuperScriptUpdated_Body_AfterThreshold_for_tanglegram.csv", check.names = FALSE)

######### Scaling #######

data.s<-scale(myRealDataBody) 
distance<-dist(data.s)
paste("Amount of missing data in distance matrix:",100*mean(is.na(distance)),"%") #% of missing data in distance

###### Cluster ########
clust_result_Body <- pvclust(as.data.frame(t(data.s)), method.dist="eu", method.hclust="ward.D2", use.cor="pairwise.complete.obs", nboot=1000, r=seq(0.5,10,by=.5)) # "euclidean distances" for method distance and "ward" for clustering method r= different size of data subsets 50% to 1000%

plot(clust_result_Body)

##################################################################################################################################################################################
##################################################################################################################################################################################
##################################################################################################################################################################################
##################################################################################################################################################################################


#####################################################################
#	Input															#
#		*SKULL														#
#####################################################################
library(ape)
library(vegan)
library(psych)
library(dendextend)
library(ggdendro)
library(pvclust)
library(ggplot2)
library(ggnewscale)
library(wesanderson)


myRealDataSkull = read.csv("CerrejonisuchusSuperScriptUpdated_Skull_AfterThreshold_for_tanglegram.csv")

######### Scaling #######

data.s<-scale(myRealDataSkull) 
distance<-dist(data.s)
paste("Amount of missing data in distance matrix:",100*mean(is.na(distance)),"%") #% of missing data in distance

###### Cluster ########
clust_result_Skull <- pvclust(as.data.frame(t(data.s)), method.dist="eu", method.hclust="ward.D2", use.cor="pairwise.complete.obs", nboot=1000, r=seq(0.5,10,by=.5)) # "euclidean distances" for method distance and "ward" for clustering method r= different size of data subsets 50% to 1000%

plot(clust_result_Skull)

# ############################################################################################################################################################
# ###############################################			TANGLEGRAM				##########################################################################
# ############################################################################################################################################################
library(phangorn)

#We take the subset of individuals that are both in the body and skull analysis
interIndividuals <- intersect(rownames(myRealDataSkull),rownames(myRealDataBody))
myRealDataBodyInter <- myRealDataBody[interIndividuals,]
myRealDataSkullInter <- myRealDataSkull[interIndividuals,]

data.s<-scale(myRealDataBodyInter) 
distance<-dist(data.s)
clust_result_BodyInter <- pvclust(as.data.frame(t(data.s)), method.dist="eu", method.hclust="ward.D2", use.cor="pairwise.complete.obs", nboot=1000, r=seq(0.5,10,by=.5)) # "euclidean distances" for method distance and "ward" for clustering method r= different size of data subsets 50% to 1000%

data.s<-scale(myRealDataSkullInter) 
distance<-dist(data.s)
clust_result_SkullInter <- pvclust(as.data.frame(t(data.s)), method.dist="eu", method.hclust="ward.D2", use.cor="pairwise.complete.obs", nboot=1000, r=seq(0.5,10,by=.5)) # "euclidean distances" for method distance and "ward" for clustering method r= different size of data subsets 50% to 1000%

#Tanglegram
comp_clust_Body <- as.dendrogram(clust_result_BodyInter$hclust) #extract cluster from pvclust result
comp_clust_Skull <- as.dendrogram(clust_result_SkullInter$hclust) #extract cluster from pvclust result
#comp_tree_eq <- as.dendrogram(force.ultrametric(tree = tree_eq,method="extend")) #force a phylogenetic tree as a dendrogram, which requires an ultrametric tree. The tree is a randomly sampled trees from the most parsimonious pool


cladeLabels <- c("Dyrosauridae","Thalattosuchia","Crocodilia","Pholidosauridae or Dyrosauridae") #When 4 clades
cladeColors <- wes_palette(name = "Darjeeling1", type = "continuous")
names(cladeColors)<- cladeLabels

myCladesInterSorted <- as.vector(myCladesBody[labels(comp_clust_Body),])

tanglegram(comp_clust_Body,comp_clust_Skull, fast = TRUE, margin_inner = 13,main_left="Body Ratio Cluster",main_right="Skull Ratio Cluster",axes=FALSE,cex_main=1.5,color_lines = cladeColors[myCladesInterSorted]) #creates tanglegram

  
pdf("Tanglegram.pdf", width=12, height=7)
  par(mfrow=c(2,1))
	tanglegram(comp_clust_Body,comp_clust_Skull, fast = TRUE, margin_inner = 13,main_left="Body Ratio Cluster",main_right="Skull Ratio Cluster",axes=FALSE,cex_main=1.5,color_lines = cladeColors[myCladesInterSorted]) #creates tanglegram
dev.off()


#Mantel test: phenotypic distance VS phylogenetic distance
phylo_dist_eq <- distTips(tree_eq,method="patristic")

mantel_phenoVSphylo_eq <- mantel(xdis=d,ydis=phylo_dist_eq,permutations=1000)



